"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Parameter_1 = require("./Parameter");
var _ = require("lodash");
var Param_1 = require("../decorators/parameters/Param");
function getRoutes(target) {
    if (!Reflect.hasOwnMetadata('custom:routes', target)) {
        Reflect.defineMetadata('custom:routes', {}, target);
    }
    return Reflect.getOwnMetadata('custom:routes', target);
}
exports.getRoutes = getRoutes;
function getBaseUrl(target) {
    return Reflect.getOwnMetadata('custom:baseUrl', target);
}
exports.getBaseUrl = getBaseUrl;
function setBaseUrl(target, baseUrl) {
    Reflect.defineMetadata('custom:baseUrl', baseUrl, target);
}
exports.setBaseUrl = setBaseUrl;
function buildUrl(target, method, url, root) {
    function nomalizeUrl(url) {
        if (url)
            return url.startsWith('/') ? url : '/' + url;
        return '';
    }
    var parameters = Parameter_1.getParameters(target);
    var rootUrl = root ? nomalizeUrl(root) : null;
    var baseUrl = nomalizeUrl(rootUrl ? rootUrl + '/' + getBaseUrl(target) : getBaseUrl(target)) || '/';
    var returnUrl = (baseUrl.length === 1 && url ? nomalizeUrl(url) : baseUrl + nomalizeUrl(url));
    var params = parameters[method] || [];
    _.each(_.sortBy(params, function (p) { return p.index; }), function (parameter) {
        if (parameter instanceof Param_1.ParamParameter) {
            returnUrl += ('/:' + parameter.name);
        }
    });
    return returnUrl;
}
exports.buildUrl = buildUrl;

//# sourceMappingURL=Route.js.map
